@@ -1,11 +1,12 @@
 # Copyright (c) OpenMMLab. All rights reserved.
+from .ascend_util import (batch_images_to_levels,
+                          get_max_num_gt_division_factor, masked_fill)
 from .collect_env import collect_env
 from .compat_config import compat_cfg
 from .logger import get_caller_name, get_root_logger, log_img_scale
 from .memory import AvoidCUDAOOM, AvoidOOM
 from .misc import find_latest_checkpoint, update_data_root
 from .replace_cfg_vals import replace_cfg_vals
-from .rfnext import rfnext_init_model
 from .setup_env import setup_multi_processes
 from .split_batch import split_batch
 from .util_distribution import build_ddp, build_dp, get_device
@@ -15,5 +16,5 @@ __all__ = [
     'update_data_root', 'setup_multi_processes', 'get_caller_name',
     'log_img_scale', 'compat_cfg', 'split_batch', 'build_ddp', 'build_dp',
     'get_device', 'replace_cfg_vals', 'AvoidOOM', 'AvoidCUDAOOM',
-    'rfnext_init_model'
+    'get_max_num_gt_division_factor', 'masked_fill', 'batch_images_to_levels'
 ]
